@@ -21,7 +21,7 @@
 #include <stdlib.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
-#include <gconf/gconf.h>
+#include <gio/gio.h>
 
 #include "main.h"
 #include "storage-manager.h"
@@ -49,7 +49,7 @@ storage_manager_disconnected_cb (AlmanahStorageManager *self, const gchar *gpgme
 	}
 
 	g_object_unref (almanah->storage_manager);
-	g_object_unref (almanah->gconf_client);
+	g_object_unref (almanah->settings);
 	g_object_unref (almanah->page_setup);
 	g_object_unref (almanah->print_settings);
 
@@ -61,6 +61,32 @@ storage_manager_disconnected_cb (AlmanahStorageManager *self, const gchar *gpgme
 	exit (0);
 }
 
+gboolean
+almanah_run_on_screen (GdkScreen *screen, const gchar *commandline, GError **error)
+{
+	gboolean retval;
+	GAppInfo *appinfo;
+	GdkAppLaunchContext *context;
+
+	appinfo = g_app_info_create_from_commandline (commandline,
+                                                "Almanah Execute",
+                                                G_APP_INFO_CREATE_NONE,
+                                                error);
+
+	if (!appinfo)
+		return FALSE;
+
+	context = gdk_display_get_app_launch_context (gdk_screen_get_display (screen));
+	gdk_app_launch_context_set_screen (context, screen);
+
+	retval = g_app_info_launch (appinfo, NULL, G_APP_LAUNCH_CONTEXT (context), error);
+
+	g_object_unref (context);
+	g_object_unref (appinfo);
+
+	return retval;
+}
+
 void
 almanah_quit (void)
 {
@@ -73,8 +99,6 @@ almanah_quit (void)
 		gtk_widget_destroy (almanah->search_dialog);
 	if (almanah->date_entry_dialog != NULL)
 		gtk_widget_destroy (almanah->date_entry_dialog);
-	if (almanah->import_dialog != NULL)
-		gtk_widget_destroy (almanah->import_dialog);
 #ifdef ENABLE_ENCRYPTION
 	if (almanah->preferences_dialog != NULL)
 		gtk_widget_destroy (almanah->preferences_dialog);
@@ -94,12 +118,11 @@ main (int argc, char *argv[])
 {
 	GOptionContext *context;
 	GError *error = NULL;
-	gboolean debug = FALSE, import_mode = FALSE;
+	gboolean debug = FALSE;
 	gchar *db_filename;
 
 	const GOptionEntry options[] = {
 		{ "debug", 0, 0, G_OPTION_ARG_NONE, &debug, N_("Enable debug mode"), NULL },
-		{ "import-mode", 0, 0, G_OPTION_ARG_NONE, &import_mode, N_("Enable import mode"), NULL },
 		{ NULL }
 	};
 
@@ -109,7 +132,7 @@ main (int argc, char *argv[])
 	textdomain (GETTEXT_PACKAGE);
 #endif
 
-	gtk_set_locale ();
+	g_thread_init (NULL);
 	gtk_init (&argc, &argv);
 	g_set_application_name (_("Almanah Diary"));
 	gtk_window_set_default_icon_name ("almanah");
@@ -139,11 +162,9 @@ main (int argc, char *argv[])
 	/* Setup */
 	almanah = g_new0 (Almanah, 1);
 	almanah->debug = debug;
-	almanah->import_mode = import_mode;
 
-	/* Open GConf */
-	almanah->gconf_client = gconf_client_get_default ();
-	gconf_client_add_dir (almanah->gconf_client, "/apps/almanah", GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
+	/* Open GSettings */
+	almanah->settings = g_settings_new ("org.gnome.almanah");
 
 	/* Ensure the DB directory exists */
 	if (g_file_test (g_get_user_data_dir (), G_FILE_TEST_IS_DIR) == FALSE)
