@@ -25,8 +25,10 @@
 #include "interface.h"
 #include "main.h"
 #include "printing.h"
+#include "widgets/calendar.h"
 
 #define TITLE_MARGIN_BOTTOM 15 /* margin under the title, in pixels */
+#define IMPORTANT_MARGIN_TOP 3 /* margin above the "important" paragraph (and below the title), in pixels */
 #define ENTRY_MARGIN_BOTTOM 10 /* margin under the entry, in pixels */
 #define MAX_ORPHANS 3 /* maximum number of orphan lines to be forced to the next page */
 #define PAGE_MARGIN 20 /* left- and right-hand page margin size, in pixels */
@@ -36,8 +38,8 @@ typedef struct {
 	GDate *start_date;
 	GDate *end_date;
 	GDate *current_date;
-	GtkCalendar *start_calendar;
-	GtkCalendar *end_calendar;
+	AlmanahCalendar *start_calendar;
+	AlmanahCalendar *end_calendar;
 	GtkSpinButton *line_spacing_spin_button;
 	gdouble line_spacing;
 	guint current_line;
@@ -241,15 +243,17 @@ static gboolean
 print_entry (GtkPrintOperation *operation, GtkPrintContext *context, AlmanahPrintOperation *almanah_operation)
 {
 	AlmanahEntry *entry;
-	gchar title[100], *title_markup;
-	PangoLayout *title_layout = NULL, *entry_layout;
+	gchar title[100], *markup;
+	PangoLayout *title_layout = NULL, *important_layout = NULL, *entry_layout;
 	PangoLayoutLine *entry_line;
 	PangoRectangle logical_extents;
 	gint height, line_height;
 	guint i;
-	gdouble title_y = 0, entry_y;
+	gdouble title_y = 0, important_y = 0, entry_y;
 	cairo_t *cr = NULL;
 
+	entry = almanah_storage_manager_get_entry (almanah->storage_manager, almanah_operation->current_date);
+
 	if (almanah_operation->current_line == 0) {
 		/* Set up the title layout */
 		title_layout = gtk_print_context_create_pango_layout (context);
@@ -257,13 +261,32 @@ print_entry (GtkPrintOperation *operation, GtkPrintContext *context, AlmanahPrin
 
 		/* Translators: This is a strftime()-format string for the date displayed above each printed entry. */
 		g_date_strftime (title, sizeof (title), _("%A, %e %B %Y"), almanah_operation->current_date);
-		title_markup = g_strdup_printf ("<b>%s</b>", title);
-		pango_layout_set_markup (title_layout, title_markup, -1);
-		g_free (title_markup);
+		markup = g_strdup_printf ("<b>%s</b>", title);
+		pango_layout_set_markup (title_layout, markup, -1);
+		g_free (markup);
 
 		title_y = almanah_operation->y;
 		pango_layout_get_pixel_size (title_layout, NULL, &height);
-		almanah_operation->y += height + TITLE_MARGIN_BOTTOM;
+		almanah_operation->y += height;
+
+		if (entry != NULL && almanah_entry_is_important (entry) == TRUE) {
+			/* State that it's an important entry */
+			important_layout = gtk_print_context_create_pango_layout (context);
+			pango_layout_set_width (title_layout, (gtk_print_context_get_width (context) - 2 * PAGE_MARGIN) * PANGO_SCALE);
+
+			markup = g_strdup_printf ("<i>%s</i>", _("This entry is marked as important."));
+			pango_layout_set_markup (important_layout, markup, -1);
+			g_free (markup);
+
+			/* If the important paragraph is displayed, it's displayed IMPORTANT_MARGIN_TOP pixels below the bottom of the title
+			 * paragraph, and then the entry content is displayed TITLE_MARGIN_BOTTOM pixels below the bottom of the important paragraph. */
+			almanah_operation->y += IMPORTANT_MARGIN_TOP;
+			important_y = almanah_operation->y;
+			pango_layout_get_pixel_size (important_layout, NULL, &height);
+			almanah_operation->y += height;
+		}
+
+		almanah_operation->y += TITLE_MARGIN_BOTTOM;
 	}
 
 	/* Set up the entry layout */
@@ -271,8 +294,6 @@ print_entry (GtkPrintOperation *operation, GtkPrintContext *context, AlmanahPrin
 	pango_layout_set_width (entry_layout, (gtk_print_context_get_width (context) - 2 * PAGE_MARGIN) * PANGO_SCALE);
 	pango_layout_set_ellipsize (entry_layout, PANGO_ELLIPSIZE_NONE);
 
-	entry = almanah_storage_manager_get_entry (almanah->storage_manager, almanah_operation->current_date);
-
 	if (entry == NULL || almanah_entry_is_empty (entry)) {
 		gchar *entry_text = g_strdup_printf ("<i>%s</i>", _("No entry for this date."));
 		pango_layout_set_markup (entry_layout, entry_text, -1);
@@ -280,7 +301,7 @@ print_entry (GtkPrintOperation *operation, GtkPrintContext *context, AlmanahPrin
 		GtkTextIter start, end;
 
 		gtk_text_buffer_set_text (almanah_operation->buffer, "", 0);
-		if (almanah_entry_get_content (entry, almanah_operation->buffer, TRUE, NULL) == TRUE) {
+		if (almanah_entry_get_content (entry, almanah_operation->buffer, FALSE, NULL) == TRUE) {
 			gtk_text_buffer_get_bounds (almanah_operation->buffer, &start, &end);
 			lay_out_entry (entry_layout, &start, &end);
 		}
@@ -290,7 +311,7 @@ print_entry (GtkPrintOperation *operation, GtkPrintContext *context, AlmanahPrin
 		g_object_unref (entry);
 
 	/* Check we're not orphaning things */
-	entry_line = pango_layout_get_line_readonly (entry_layout, MIN (pango_layout_get_line_count (entry_layout) - 1, almanah_operation->current_line + MAX_ORPHANS));
+	entry_line = pango_layout_get_line_readonly (entry_layout, MIN ((guint) pango_layout_get_line_count (entry_layout) - 1, almanah_operation->current_line + MAX_ORPHANS));
 	pango_layout_line_get_pixel_extents (entry_line, NULL, &logical_extents);
 	line_height = pango_layout_get_spacing (entry_layout) / PANGO_SCALE + (gint) (almanah_operation->line_spacing * ((gdouble) logical_extents.height));
 
@@ -298,6 +319,8 @@ print_entry (GtkPrintOperation *operation, GtkPrintContext *context, AlmanahPrin
 		/* Not enough space on the page to contain the title and orphaned lines */
 		if (title_layout != NULL)
 			g_object_unref (title_layout);
+		if (important_layout != NULL)
+			g_object_unref (important_layout);
 		g_object_unref (entry_layout);
 
 		almanah_operation->current_line = 0;
@@ -312,6 +335,12 @@ print_entry (GtkPrintOperation *operation, GtkPrintContext *context, AlmanahPrin
 			/* Draw the title */
 			cairo_move_to (cr, PAGE_MARGIN, title_y);
 			pango_cairo_show_layout (cr, title_layout);
+
+			if (important_layout != NULL) {
+				/* Draw the important paragraph */
+				cairo_move_to (cr, PAGE_MARGIN, important_y);
+				pango_cairo_show_layout (cr, important_layout);
+			}
 		}
 	}
 
@@ -329,6 +358,8 @@ print_entry (GtkPrintOperation *operation, GtkPrintContext *context, AlmanahPrin
 			/* Paint the rest on the next page */
 			if (title_layout != NULL)
 				g_object_unref (title_layout);
+			if (important_layout != NULL)
+				g_object_unref (important_layout);
 			g_object_unref (entry_layout);
 
 			almanah_operation->current_line = i;
@@ -350,6 +381,8 @@ print_entry (GtkPrintOperation *operation, GtkPrintContext *context, AlmanahPrin
 
 	if (title_layout != NULL)
 		g_object_unref (title_layout);
+	if (important_layout != NULL)
+		g_object_unref (important_layout);
 	g_object_unref (entry_layout);
 
 	almanah_operation->current_line = 0;
@@ -411,10 +444,11 @@ create_custom_widget_cb (GtkPrintOperation *operation, AlmanahPrintOperation *al
 	GtkBox *vbox, *hbox;
 
 	/* Start and end calendars */
-	start_calendar = gtk_calendar_new ();
-	g_signal_connect (start_calendar, "month-changed", G_CALLBACK (almanah_calendar_month_changed_cb), NULL);
-	end_calendar = gtk_calendar_new ();
-	g_signal_connect (end_calendar, "month-changed", G_CALLBACK (almanah_calendar_month_changed_cb), NULL);
+	start_calendar = almanah_calendar_new ();
+	end_calendar = almanah_calendar_new ();
+
+	g_object_set (G_OBJECT (start_calendar), "show-details", FALSE, NULL);
+	g_object_set (G_OBJECT (end_calendar), "show-details", FALSE, NULL);
 
 	start_label = GTK_LABEL (gtk_label_new (_("Start date:")));
 	gtk_misc_set_alignment (GTK_MISC (start_label), 0.0, 0.5);
@@ -430,8 +464,8 @@ create_custom_widget_cb (GtkPrintOperation *operation, AlmanahPrintOperation *al
 	gtk_table_attach (table, GTK_WIDGET (start_label), 0, 1, 0, 1, GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
 	gtk_table_attach (table, GTK_WIDGET (end_label), 1, 2, 0, 1, GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
 
-	almanah_operation->start_calendar = GTK_CALENDAR (start_calendar);
-	almanah_operation->end_calendar = GTK_CALENDAR (end_calendar);
+	almanah_operation->start_calendar = ALMANAH_CALENDAR (start_calendar);
+	almanah_operation->end_calendar = ALMANAH_CALENDAR (end_calendar);
 
 	/* Line spacing */
 	line_spacing_label = GTK_LABEL (gtk_label_new (_("Line spacing:")));
@@ -450,8 +484,8 @@ create_custom_widget_cb (GtkPrintOperation *operation, AlmanahPrintOperation *al
 	gtk_widget_show_all (GTK_WIDGET (vbox));
 
 	/* Make sure they have the dates with entries marked */
-	almanah_calendar_month_changed_cb (GTK_CALENDAR (start_calendar), NULL);
-	almanah_calendar_month_changed_cb (GTK_CALENDAR (end_calendar), NULL);
+	almanah_calendar_select_today (almanah_operation->start_calendar);
+	almanah_calendar_select_today (almanah_operation->end_calendar);
 
 	return GTK_WIDGET (vbox);
 }
@@ -459,16 +493,12 @@ create_custom_widget_cb (GtkPrintOperation *operation, AlmanahPrintOperation *al
 static void
 custom_widget_apply_cb (GtkPrintOperation *operation, GtkWidget *widget, AlmanahPrintOperation *almanah_operation)
 {
-	guint year, month, day;
-
 	/* Start date */
-	gtk_calendar_get_date (almanah_operation->start_calendar, &year, &month, &day);
-	g_date_set_dmy (almanah_operation->start_date, day, month + 1, year);
-	g_date_set_dmy (almanah_operation->current_date, day, month + 1, year);
+	almanah_calendar_get_date (almanah_operation->start_calendar, almanah_operation->start_date);
+	almanah_calendar_get_date (almanah_operation->start_calendar, almanah_operation->current_date);
 
 	/* End date */
-	gtk_calendar_get_date (almanah_operation->end_calendar, &year, &month, &day);
-	g_date_set_dmy (almanah_operation->end_date, day, month + 1, year);
+	almanah_calendar_get_date (almanah_operation->end_calendar, almanah_operation->end_date);
 
 	/* Ensure they're in order */
 	if (g_date_compare (almanah_operation->start_date, almanah_operation->end_date) > 0) {
